<?php $TRANSLATIONS = array(
"Pictures" => "Pildid",
"Shared by" => "Jagas",
"Share" => "Jaga",
"The \"Image Viewer\" application also need to be enabled to use this application." => "\"Pildivaataja\" rakendus tuleb sisse lülitada, et seda rakendust kasutada."
);
